Learn R Programming

ribiosPlot (version 1.3.0)

PCAScoreMatrix: Construct a S3-class PCAScoreMatrix object

Description

Construct a S3-class PCAScoreMatrix object

Usage

PCAScoreMatrix(scoreMatrix, expVar)

Value

A S3-class PCAScoreMatrix object, which is a score matrix with explained variances (expVar) as attribute.

Arguments

scoreMatrix

Numeric matrix, objects in rows and PCs in columns

expVar

Numeric vector, length must equal the number of columns of scoreMatrix, explained variance by respective PCs

See Also

as.matrix.PCAScoreMatrix, expVar.PCAScoreMatrix, print.PCAScoreMatrix. This function is usually not called by the end user; instead, it is used by the function pcaScores

Examples

Run this code

myPCmat <- PCAScoreMatrix(matrix(rnorm(15),ncol=3), c(0.25, 0.15, 0.1))
myPCmat

Run the code above in your browser using DataLab