Learn R Programming

ribiosPlot (version 1.3.0)

compactTrellis: Return a compact setting for lattice plots, useful for preparing publications

Description

The function returns a set of lattice options that are useful for compact figures, with less room for padding and therefore more room for the figure. It is often used to prepare for publications.

Usage

compactTrellis()

Arguments

Value

A list that can be used in lattice.options

Examples

Run this code

opts <- compactTrellis()

Run the code above in your browser using DataLab