Mimicking the graphics::smoothScatter behaviour for GGally::ggpairs
ggSmoothScatter(
data,
mapping,
colours = colorRampPalette(c("white", blues9[5:9], "black"))(256),
xlim = NULL,
ylim = NULL,
...
)Data to be visualized, normally not directly set by the user
Data mapping, normally not directly set by the user
Colours to be used
NULL or a vector of two numbers
NULL or a vector of two numbers
Other parameters passed to stat_density_2d