Learn R Programming

ribiosPlot (version 1.3.0)

intRange: Return a range defined by integers

Description

The function is similar to range but returns integer ranges that are just outside the real range: i.e. the floor of the left range and the ceiling of the right range.

Usage

intRange(x, na.rm = TRUE)

Value

A vector of integers of length 2.

Arguments

x

A numeric vector

na.rm

Logical, whether NA should be removed

Author

Jitao David Zhang <jitao_david.zhang@roche.com>

Examples

Run this code

intRange(rnorm(100))

Run the code above in your browser using DataLab