Learn R Programming

ribiosPlot (version 1.3.0)

nonNull: Make sure that x is assigned a reasonable value

Description

Make sure that x is assigned a reasonable value

Usage

nonNull(x, default, length = NULL, defaultNULL.ok = FALSE)

Value

non-null values

Arguments

x

Any vector

default

A default value

length

Desired length

defaultNULL.ok

Logical, whether the default can be NULL or not