Learn R Programming

ribiosPlot (version 1.3.0)

panel.lmSmooth: Correlation panel

Description

Correlation panel

Usage

panel.lmSmooth(
  x,
  y,
  col = par("col"),
  bg = NA,
  pch = par("pch"),
  cex = 0.8,
  method = "spearman",
  use = "complete",
  ...
)

Value

No return value, called for side effects as a panel function in pairs.

Arguments

x

A numeric vector

y

A numeric vector, must be of the same length as x.

col

Color

bg

Background

pch

Ponit symbol

cex

Font size

method

Correlation method, passed to cor

use

passed to cor

...

Passed to panel.smooth

This function can be used with pairs to display correlations.

See Also