Learn R Programming

ribiosPlot (version 1.3.0)

pcaScoresFromLogFC: Perform principal component analysis and derive PCA scores from a logFC matrix

Description

Perform principal component analysis and derive PCA scores from a logFC matrix

Usage

pcaScoresFromLogFC(lfcMat, reference = 0, choices, reverse = c(FALSE, FALSE))

Value

A PCAScoreMatrix object containing the PCA scores derived from the log fold-change matrix.

Arguments

lfcMat

Log fold-chnage matrix, genes (features) in rows and samples in columns

reference

The reference value that should be set as 0 in the scores, default: 0

choices

How many PCs should be retured. Passed to pcaScores

reverse

Whether the axes should be reversed. Passed to pcaScores

Perform PCA and get scores from a logFC matrix by setting a pseudo profile of no change (0 for all features) at the origin point

Examples

Run this code

lfcMat <- matrix(rnorm(9), nrow=3)
pcaScoresFromLogFC(lfcMat)

Run the code above in your browser using DataLab