Plot PCA loading
plotPCAloading(
loadings,
x = 1L,
y = 2L,
circle = FALSE,
title = "",
subtitle = "",
...
)No return value, called for side effects (plotting).
PCA loadings
Integer, which loading is to be visualized on the X axis?
Integer, the loading to be visualized on the X axis.
Logical, whether draw circle or not
Character string
Character string
Passed to plot