Learn R Programming

ribiosPlot (version 1.3.0)

plotVenn: Plot Venn object of the Vennerable package

Description

The function plots Venn objects from the Vennerable package with custom margins that better suit publication figures.

Usage

plotVenn(
  venn,
  main = "",
  show = list(FaceText = "weight", Universe = FALSE),
  ...
)

Value

Side effect is used - a plot is generated.

Arguments

venn

Venn object from the Vennerable package

main

Figure title

show

Named list controlling which elements to display. Supported elements: Universe (logical), Sets (logical), SetLabels (logical), DarkMatter (logical), Faces (logical), FaceText (character, e.g. "weight").

...

Other parameters passed to Vennerable::compute.Venn

Examples

Run this code

if (requireNamespace("Vennerable", quietly = TRUE)) {
  myVenn <- list(A = LETTERS[1:24], B = LETTERS[3:8], C = LETTERS[5:9])
  plotVenn(Vennerable::Venn(myVenn), main = "Letters")
}

Run the code above in your browser using DataLab