Learn R Programming

ribiosPlot (version 1.3.0)

qBreaks: Internal function to re-calculate breaks of histograms when x-axis is clipped

Description

The function calculates the new break numbers caused by the clipping of x axis. This is usally larger than the original number of breaks .

Usage

qBreaks(x, quantiles = c(0, 0.99), breaks = 100)

Value

Integer: number of breaks

Arguments

x

Value to draw histgrams with

quantiles

Quantiles of x that determine the clip boundary of x-axis

breaks

Integer, number of breaks applied to original data

Author

Jitao David Zhang <jitao_david.zhang@roche.com>

See Also

This function is directly used by qHist

Examples

Run this code

testVal <- rnorm(1000)
qBreaks(testVal, quantiles=c(0.25, 0.75), breaks=100)

Run the code above in your browser using DataLab