The object returned by the hist function, with an extra item
named quantiles.
Arguments
x
Value to draw the histogram
quantiles
Numeric values or NULL; in case of numeric values,
at the corresponding quantile values vertical lines and text labels are
drawn; if set to NULL, no extra items will display. See examples
below.
breaks
Integer, number of breaks
qlty
Type of vertical quantile lines
qlwd
Width of vertical quantile lines
qcol
Color of vertical quantile lines
...
Other parameters that are passed to hist
Author
Jitao David Zhang <jitao_david.zhang@roche.com>
Details
The appends vertical lines and texts to histograms produced by hist.
This can be useful in unspecific filtering of expression data.