Learn R Programming

ribiosPlot (version 1.3.0)

ribiosPlot-package: ribiosPlot: Plotting Module of the 'ribios' Software Suite

Description

Provides data structures and functions for data transformation and visualization in computational biology in drug discovery as part of the 'ribios' software suite. Zhang (2025) https://github.com/bedapub/ribiosPlot.

Arguments

Author

Maintainer: Jitao David Zhang jitao_david.zhang@roche.com (ORCID) [contributor]

See Also