The object returned by the hist function, with an extra item
named quantiles.
Arguments
x
Value to draw the histogram
xclip
Quantiles of x-values that should be displayed; values outside
of this range are not shown in the histogram
breaks
A integer number indicating how many breaks should the
original unclipped data have; the function will automatically
re-calculate the breaks of the clipped data so that they look consistent.
quantiles
Numeric values or NULL; in case of numeric values,
at the corresponding quantile values vertical lines and text labels are
drawn; if set to NULL, no extra items will display. See examples
below.
qlty
Type of vertical quantile lines
qlwd
Width of vertical quantile lines
qcol
Color of vertical quantile lines
...
Other parameters that are passed to hist
Author
Jitao David Zhang <jitao_david.zhang@roche.com>
Details
The function clips (subsets) x-axis and recalcualte the breaks so that the
clipped image looks like a real subset of the original data.
See Also
qHist, which draws quantile line and texts onto histograms.