PCAScoreMatrix: Construct a S3-class PCAScoreMatrix object
Description
Construct a S3-class PCAScoreMatrix object
Usage
PCAScoreMatrix(scoreMatrix, expVar)
Value
A S3-class PCAScoreMatrix object, which is a score matrix
with explained variances (expVar) as attribute.
Arguments
scoreMatrix
Numeric matrix, objects in rows and PCs in columns
expVar
Numeric vector, length must equal the number of columns of
scoreMatrix, explained variance by respective PCs
See Also
as.matrix.PCAScoreMatrix, expVar.PCAScoreMatrix,
print.PCAScoreMatrix. This function is usually not called by the end
user; instead, it is used by the function pcaScores