ipdf is a shortcut in case PDF is used as the device, with the twist
that useDingbats is set to FALSE by default. See NOTE.
dev.print will make a R-script fail if the session is not interactive
(e.g. when the script is excuted with the -f option from R
command line). Function idev checks first whether the session is
interative, and executes dev.print only if the session is
interactive.
A commonly used shortcut is ipdf, which prints the current device to
a PDF file.