panel.cor: Correlation panel for pairs
Description
Correlation panel for pairs
Usage
panel.cor(x, y, digits = 2, prefix = "", cex.cor, ...)
Value
No return value, called for side effects as a panel function
in pairs.
Arguments
- x
A numeric vector
- y
A numeric vector, must be of the same length as x.
- digits
Integer, number of digits to show
- prefix
Prefix of the label
- cex.cor
Numeric, if missing, automatically guessed
- ...
Passed to cor.
This function can be used with pairs to display correlations.