Correlation panel
panel.lmSmooth(
x,
y,
col = par("col"),
bg = NA,
pch = par("pch"),
cex = 0.8,
method = "spearman",
use = "complete",
...
)No return value, called for side effects as a panel function
in pairs.
A numeric vector
A numeric vector, must be of the same length as x.
Color
Background
Ponit symbol
Font size
Correlation method, passed to cor
passed to cor
Passed to panel.smooth
This function can be used with pairs to display correlations.