powered by
Perform principal component analysis and derive PCA scores from a logFC matrix
pcaScoresFromLogFC(lfcMat, reference = 0, choices, reverse = c(FALSE, FALSE))
A PCAScoreMatrix object containing the PCA scores derived from the log fold-change matrix.
PCAScoreMatrix
Log fold-chnage matrix, genes (features) in rows and samples in columns
The reference value that should be set as 0 in the scores, default: 0
How many PCs should be retured. Passed to pcaScores
pcaScores
Whether the axes should be reversed. Passed to pcaScores
Perform PCA and get scores from a logFC matrix by setting a pseudo profile of no change (0 for all features) at the origin point
lfcMat <- matrix(rnorm(9), nrow=3) pcaScoresFromLogFC(lfcMat)
Run the code above in your browser using DataLab