powered by
The function calculates the new break numbers caused by the clipping of x axis. This is usally larger than the original number of breaks .
qBreaks(x, quantiles = c(0, 0.99), breaks = 100)
Integer: number of breaks
Value to draw histgrams with
Quantiles of x that determine the clip boundary of x-axis
Integer, number of breaks applied to original data
Jitao David Zhang <jitao_david.zhang@roche.com>
This function is directly used by qHist
qHist
testVal <- rnorm(1000) qBreaks(testVal, quantiles=c(0.25, 0.75), breaks=100)
Run the code above in your browser using DataLab