Provides data structures and functions for data transformation and visualization in computational biology in drug discovery as part of the 'ribios' software suite. Zhang (2025) https://github.com/bedapub/ribiosPlot.
Maintainer: Jitao David Zhang jitao_david.zhang@roche.com (ORCID) [contributor]
Useful links: